pub mod packet;
pub mod player;

use std::{collections::HashMap, sync::LazyLock};

use player::PlayerActor;
use tokio::{net::TcpListener, sync::RwLock};
use tracing::{error, info};
use tracing_subscriber::{layer::SubscriberExt, util::SubscriberInitExt};
use xtra::Address;

pub fn clients() -> &'static RwLock<HashMap<u128, Address<PlayerActor>>> {
  static CLIENTS: LazyLock<RwLock<HashMap<u128, Address<PlayerActor>>>> = LazyLock::new(|| RwLock::default());

  &CLIENTS
}

#[tokio::main]
async fn main() {
  //.with(EnvFilter::from_default_env())
  tracing_subscriber::registry().with(tracing_subscriber::fmt::layer()).init();
  let tcp = TcpListener::bind("0.0.0.0:1027").await.unwrap();

  info!("listening on port 1027");
  loop {
    match tcp.accept().await {
      Ok((stream, addr)) => {
        PlayerActor::new_connection(stream, addr);
      }
      Err(error) => {
        error!("failed to handle connection: {error:?}");
      }
    }
  }

  // let socket = Arc::new(UdpSocket::bind("0.0.0.0:1027").await.unwrap());
  // let mut packet = [0u8; 1024];
}
